"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));

var _createClass2 = _interopRequireDefault(require("@babel/runtime/helpers/createClass"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _url = _interopRequireDefault(require("url"));

var _app = require("meetup-web-mocks/lib/app");

var _api = require("meetup-web-mocks/lib/api");

var clickState = _interopRequireWildcard(require("mwp-tracking-plugin/lib/util/clickState"));

var _fetchQueries = _interopRequireDefault(require("./fetchQueries"));

var URLSearchParams = _url.default.URLSearchParams;
clickState.setClickCookie = jest.fn();

global.FormData = function () {};

global.URLSearchParams = URLSearchParams;
global.window = {
  location: {
    search: ''
  }
};
jest.mock('js-cookie', function () {
  var get = jest.fn(function (name) {
    return "".concat(name, " value");
  });
  var set = jest.fn(function (name, value) {
    return "".concat(name, " set to ").concat(value);
  });
  return {
    get: get,
    set: set,
    withConverter: jest.fn(function () {
      return {
        get: get,
        set: set
      };
    })
  };
});
describe('fetchQueries', function () {
  var API_URL = new URL('http://api.example.com/');
  var csrfJwt = 'x-mwp-csrf_dev-header value';
  var getQueries = [(0, _app.mockQuery)({
    params: {}
  })];
  var POSTQueries = [(0, _objectSpread2.default)({}, (0, _app.mockQuery)({
    params: {}
  }), {
    meta: {
      method: 'POST'
    }
  })];
  var meta = {
    foo: 'bar',
    clickTracking: {
      history: []
    }
  };
  var responses = [_api.MOCK_GROUP];

  var fakeSuccess = function fakeSuccess() {
    return Promise.resolve({
      json: function json() {
        return Promise.resolve({
          responses: responses
        });
      },
      headers: {
        get: function get(key) {
          return {
            'x-mwp-csrf_dev-header': csrfJwt
          }[key];
        }
      }
    });
  };

  var fakeSuccessError = function fakeSuccessError() {
    return Promise.resolve({
      json: function json() {
        return Promise.resolve({
          error: 'you lose',
          message: 'fakeSuccessError'
        });
      },
      headers: {
        get: function get(key) {
          return {
            'x-mwp-csrf_dev-': csrfJwt
          }[key];
        }
      }
    });
  };

  it('returns an object with successes and errors arrays', function () {
    spyOn(global, 'fetch').and.callFake(fakeSuccess);
    return (0, _fetchQueries.default)(API_URL.toString())(getQueries).then(function (response) {
      expect(response.successes).toEqual([{
        query: getQueries[0],
        response: responses[0]
      }]);
      expect(response.errors).toEqual([]);
    });
  });
  it('returns a promise that will reject when response contains error prop', function () {
    spyOn(global, 'fetch').and.callFake(fakeSuccessError);
    return (0, _fetchQueries.default)(API_URL.toString())(getQueries).then(function (response) {
      return expect(true).toBe(false);
    }, function (err) {
      return expect(err).toEqual(jasmine.any(Error));
    });
  });
  it('calls fetch with method supplied by query', function () {
    spyOn(global, 'fetch').and.callFake(fakeSuccess);
    var query = (0, _app.mockQuery)({
      params: {}
    });
    var queries = [query];

    var methodTest = function methodTest(method) {
      return function () {
        query.meta = {
          method: method
        };
        return (0, _fetchQueries.default)(API_URL.toString())(queries).then(function (response) {
          var _global$fetch$calls$m = (0, _slicedToArray2.default)(global.fetch.calls.mostRecent().args, 2),
              config = _global$fetch$calls$m[1];

          expect(config.method).toEqual(method);
        });
      };
    };

    return methodTest('POST')().then(methodTest('PATCH')).then(methodTest('PUT')).then(methodTest('DELETE'));
  });
  describe('GET', function () {
    it('GET calls fetch with API url and queries, metadata', function () {
      spyOn(global, 'fetch').and.callFake(fakeSuccess);
      return (0, _fetchQueries.default)(API_URL.toString())(getQueries, (0, _objectSpread2.default)({}, meta)).then(function () {
        var calledWith = global.fetch.calls.mostRecent().args;
        var url = new URL(calledWith[0]);
        expect(url.origin).toBe(API_URL.origin);
        expect(url.searchParams.has('queries')).toBe(true);
        expect(url.searchParams.has('metadata')).toBe(true);
        expect(calledWith[1].method).toEqual('GET');
      });
    });
    it('passes along __set_geoip querystring param', function () {
      spyOn(global, 'fetch').and.callFake(fakeSuccess);
      var _window = global.window;
      global.window = {
        location: {
          search: '?__set_geoip=1234'
        }
      };
      return (0, _fetchQueries.default)(API_URL.toString())(getQueries, (0, _objectSpread2.default)({}, meta)).then(function () {
        var calledWith = global.fetch.calls.mostRecent().args;
        var url = new URL(calledWith[0]);
        expect(url.searchParams.has('__set_geoip')).toBe(true);
        global.window = _window;
      });
    });
    it('GET without meta calls fetch without metadata querystring params', function () {
      spyOn(global, 'fetch').and.callFake(fakeSuccess);
      return (0, _fetchQueries.default)(API_URL.toString())(getQueries).then(function () {
        var calledWith = global.fetch.calls.mostRecent().args;
        var url = new URL(calledWith[0]);
        expect(url.origin).toBe(API_URL.origin);
        expect(url.searchParams.has('queries')).toBe(true);
        expect(url.searchParams.has('metadata')).toBe(false);
        expect(calledWith[1].method).toEqual('GET');
      });
    });
  });
  describe('POST', function () {
    it('POST calls fetch with API url; csrf header; queries and metadata body params', function () {
      spyOn(global, 'fetch').and.callFake(fakeSuccess);
      return (0, _fetchQueries.default)(API_URL.toString())(POSTQueries, meta).then(function () {
        var calledWith = global.fetch.calls.mostRecent().args;
        var url = new URL(calledWith[0]);
        var options = calledWith[1];
        expect(url.toString()).toBe(API_URL.toString());
        expect(options.method).toEqual('POST'); // build a dummy url to hold the url-encoded body as searchstring

        var dummyUrl = new URL("http://example.com?".concat(options.body));
        expect(dummyUrl.searchParams.has('queries')).toBe(true);
        expect(dummyUrl.searchParams.has('metadata')).toBe(true);
        expect(options.headers['x-mwp-csrf_dev']).toEqual(csrfJwt);
      });
    });
    it('POST without meta calls fetch without metadata body params', function () {
      spyOn(global, 'fetch').and.callFake(fakeSuccess);
      return (0, _fetchQueries.default)(API_URL.toString())(POSTQueries).then(function () {
        var calledWith = global.fetch.calls.mostRecent().args;
        var url = new URL(calledWith[0]);
        var options = calledWith[1];
        expect(url.toString()).toBe(API_URL.toString());
        expect(options.method).toEqual('POST');
        var dummyUrl = new URL("http://example.com?".concat(options.body));
        expect(dummyUrl.searchParams.has('queries')).toBe(true);
        expect(dummyUrl.searchParams.has('metadata')).toBe(false);
        expect(options.headers['x-mwp-csrf_dev']).toEqual(csrfJwt);
      });
    });
  });
  describe('form data', function () {
    it('sends form data as multipart/form-data', function () {
      global.FormData =
      /*#__PURE__*/
      function () {
        function FormData() {
          (0, _classCallCheck2.default)(this, FormData);
        }

        (0, _createClass2.default)(FormData, [{
          key: "append",
          value: function append() {}
        }, {
          key: "has",
          value: function has() {
            return true;
          }
        }]);
        return FormData;
      }();

      FormData.prototype.append = jest.fn();
      var formQueries = [(0, _objectSpread2.default)({}, (0, _app.mockQuery)({
        params: new FormData()
      }), {
        meta: {
          method: 'POST'
        }
      })];
      spyOn(global, 'fetch').and.callFake(fakeSuccess);
      return (0, _fetchQueries.default)(API_URL.toString())(formQueries).then(function () {
        var calledWith = global.fetch.calls.mostRecent().args;
        var url = new URL(calledWith[0]);
        var options = calledWith[1];
        expect(options.method).toEqual('POST');
        expect(url.searchParams.has('queries')).toBe(true);
        expect(url.searchParams.has('metadata')).toBe(false);
        expect(options.headers['x-mwp-csrf_dev']).toEqual(csrfJwt);
      });
    });
  });
});
//# sourceMappingURL=fetchQueries.test.js.map