"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.config = config;
exports.flags = flags;
exports.preRenderChecklist = preRenderChecklist;
exports.default = makeRootReducer;
exports.platformReducers = void 0;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _redux = require("redux");

var _mwpApiState = require("mwp-api-state");

var _mwpRouter = require("mwp-router");

/**
 * The root level reducer for the app.
 * @module reducer
 **/
function config() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type === 'CONFIGURE') {
    return (0, _objectSpread2.default)({}, state, action.payload);
  }

  return state;
}

function flags() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type === 'UPDATE_FLAGS') {
    return (0, _objectSpread2.default)({}, state, action.payload);
  }

  return state;
}
/**
 * This reducer manages a list of boolean flags that indicate the 'ready to
 * render' state of the application. It is used exclusively by the server,
 * which triggers actions when initializing a response that should eventually
 * make all flags 'true'
 *
 * The server can then read these flags from state and render when ready
 */


function preRenderChecklist() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [false],
      _ref2 = (0, _slicedToArray2.default)(_ref, 1),
      apiDataLoaded = _ref2[0];

  var action = arguments.length > 1 ? arguments[1] : undefined;
  return [apiDataLoaded || action.type === _mwpApiState.API_RESP_COMPLETE];
}

var platformReducers = {
  api: _mwpApiState.api,
  config: config,
  flags: flags,
  preRenderChecklist: preRenderChecklist,
  routing: _mwpRouter.routing
};
/**
 * A function that builds a reducer combining platform-standard reducers and
 * app-specific reducers
 */

exports.platformReducers = platformReducers;

function makeRootReducer() {
  var appReducers = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  Object.keys(appReducers).forEach(function (reducer) {
    if (reducer in platformReducers) {
      throw new Error("'".concat(reducer, "' is a reserved platform reducer name"));
    }
  });
  return (0, _redux.combineReducers)((0, _objectSpread2.default)({}, platformReducers, appReducers));
}
//# sourceMappingURL=reducer.js.map