"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var redux = _interopRequireWildcard(require("redux"));

var _reducer = _interopRequireWildcard(require("./reducer"));

/**
 * A function that builds a reducer combining platform-standard reducers and
 * app-specific reducers
export default function makeRootReducer(appReducers = {}) {
	Object.keys(appReducers).forEach(reducer => {
		if (reducer in platformReducers) {
			throw new Error(`'${reducer}' is a reserved platform reducer name`);
		}
	});
	return combineReducers({
		...platformReducers,
		...appReducers,
	});
}
*/
redux.combineReducers = jest.fn();
describe('makeRootReducer', function () {
  it('calls combineReducers with platform reducers + supplied reducers', function () {
    redux.combineReducers.mockClear();

    var foo = function foo() {};

    var appReducers = {
      foo: foo
    };
    (0, _reducer.default)(appReducers);
    expect(redux.combineReducers).toHaveBeenCalled();
    var calledWith = redux.combineReducers.mock.calls[0][0];
    expect(calledWith).toMatchObject(_reducer.platformReducers); // all platform reducers

    expect(calledWith).toMatchObject(appReducers); // additional app reducer
  });
  it('throws error when attempting to overwrite a platform reducer', function () {
    var invalidReducerKey = Object.keys(_reducer.platformReducers)[0];
    expect(function () {
      return (0, _reducer.default)((0, _defineProperty2.default)({}, invalidReducerKey, _reducer.platformReducers[invalidReducerKey]));
    }).toThrow();
  });
});
//# sourceMappingURL=reducer.test.js.map