"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parseQueryResponse = exports.getAuthedQueryFilter = void 0;

var getIsLoggedIn = function getIsLoggedIn(member) {
  return Boolean((member || {}).id);
}; // Higher order function that provides a filtering function for queries based
// on logged-in status


var getAuthedQueryFilter = function getAuthedQueryFilter(member) {
  var isLoggedIn = getIsLoggedIn(member);
  return function (q) {
    return isLoggedIn || !q.endpoint.includes('members/self');
  };
};
/**
 * A module for middleware that would like to make external calls through `fetch`
 */


exports.getAuthedQueryFilter = getAuthedQueryFilter;

var parseQueryResponse = function parseQueryResponse(queries) {
  return function (proxyResponse) {
    if (!proxyResponse.responses) {
      throw new Error(JSON.stringify(proxyResponse)); // treat like an API error
    }

    var responses = proxyResponse.responses;

    if (queries.length !== responses.length) {
      throw new Error('Responses do not match requests');
    }

    return responses.reduce(function (categorized, response, i) {
      var targetArray = response.error ? categorized.errors : categorized.successes;
      targetArray.push({
        response: response,
        query: queries[i]
      });
      return categorized;
    }, {
      successes: [],
      errors: []
    });
  };
};

exports.parseQueryResponse = parseQueryResponse;
//# sourceMappingURL=fetchUtils.js.map