"use strict";

var _fetchUtils = require("./fetchUtils");

describe('parseQueryResponse', function () {
  it('categorizes query responses into success and failure arrays of [query, response] tuples', function () {
    var goodRef = 'foo';
    var goodQuery = {
      ref: goodRef
    };
    var goodResponse = {
      value: 'bar',
      ref: goodRef
    };
    var badRef = 'bar';
    var badQuery = {
      ref: badRef
    };
    var badResponse = {
      value: 'whatever',
      error: 'Bad news',
      ref: badRef
    };
    var proxyResponse = {
      responses: [goodResponse, badResponse]
    };
    var parse = (0, _fetchUtils.parseQueryResponse)([goodQuery, badQuery]);
    expect(parse(proxyResponse)).toEqual({
      successes: [{
        query: goodQuery,
        response: goodResponse
      }],
      errors: [{
        query: badQuery,
        response: badResponse
      }]
    });
  });
  it('errors when no responses provided', function () {
    var proxyResponse = {
      foo: 'bar'
    };
    expect(function () {
      return (0, _fetchUtils.parseQueryResponse)()(proxyResponse);
    }).toThrowError(JSON.stringify(proxyResponse));
  });
  it('errors when responses length is different from queries length', function () {
    var queries = [{}, {}];
    var responses = [{}];
    var proxyResponse = {
      responses: responses
    };
    expect(function () {
      return (0, _fetchUtils.parseQueryResponse)(queries)(proxyResponse);
    }).toThrowError(/do not match/);
  });
});
describe('getAuthedQueryFilter', function () {
  var memberSelfQuery = {
    endpoint: 'members/self',
    params: {}
  };
  var loggedIn = {
    id: 1234
  };
  var loggedOut = {
    id: 0
  }; // 'undefined' also considered logged-out

  it('returns false for "members/self" query for logged-out users', function () {
    expect((0, _fetchUtils.getAuthedQueryFilter)(loggedOut)(memberSelfQuery)).toBe(false);
    expect((0, _fetchUtils.getAuthedQueryFilter)(undefined)(memberSelfQuery)).toBe(false);
  });
  it('returns true for "members/self" for logged-in users', function () {
    expect((0, _fetchUtils.getAuthedQueryFilter)(loggedIn)(memberSelfQuery)).toBe(true);
  });
});
//# sourceMappingURL=fetchUtils.test.js.map